package logging

import (
	"flag"
	"log"

	"git.loafle.net/commons_go/config"

	"go.uber.org/zap"
)

var (
	configPath *string
)

func init() {
	configPath = flag.String("logger-config-path", "./logging.json", "The path of logger config file")
	flag.Parse()
}

var logger *zap.Logger

func Logger() *zap.Logger {
	if nil == logger {
		initializeLogger()
	}
	return logger
}

func initializeLogger() {
	var cfg zap.Config
	var err error

	conf := config.New()

	if err = conf.Load(&cfg, *configPath); nil != err {
		log.Printf("Loading of logger config has been failed [%v]", err)
		if logger, err = zap.NewDevelopment(); nil != err {
			log.Panicf("Building of logger config[Development] has been failed [%v]", err)
		}
		return
	}

	if logger, err = cfg.Build(); nil != err {
		log.Panicf("Building of logger config[%s] has been failed [%v]", *configPath, err)
	}
}
